@@ -1,9 +1,13 @@
+import os
+import tempfile
+import nbformat
+from nbconvert import PythonExporter
 from pathlib import Path
 from typing import Any, Dict, Optional, Tuple
-import logging
 import ast
+from codegraphcontext.utils.debug_log import debug_log, info_logger, error_logger, warning_logger, debug_logger
+from codegraphcontext.utils.tree_sitter_manager import execute_query
 
-logger = logging.getLogger(__name__)
 
 PY_QUERIES = {
     "imports": """
@@ -52,11 +56,6 @@ class PythonTreeSitterParser:
         self.language = generic_parser_wrapper.language
         self.parser = generic_parser_wrapper.parser
 
-        self.queries = {
-            name: self.language.query(query_str)
-            for name, query_str in PY_QUERIES.items()
-        }
-
     def _get_node_text(self, node) -> str:
         return node.text.decode('utf-8')
 
@@ -97,38 +96,65 @@ class PythonTreeSitterParser:
                     return self._get_node_text(first_child.children[0])
         return None
 
-    def parse(self, file_path: Path, is_dependency: bool = False) -> Dict:
+    def parse(self, file_path: Path, is_dependency: bool = False, is_notebook: bool = False) -> Dict:
         """Parses a file and returns its structure in a standardized dictionary format."""
-        with open(file_path, "r", encoding="utf-8") as f:
-            source_code = f.read()
-        
-        tree = self.parser.parse(bytes(source_code, "utf8"))
-        root_node = tree.root_node
+        original_file_path = file_path
+        temp_py_file = None
+        source_code = None
 
-        functions = self._find_functions(root_node)
-        functions.extend(self._find_lambda_assignments(root_node))
-        classes = self._find_classes(root_node)
-        imports = self._find_imports(root_node)
-        function_calls = self._find_calls(root_node)
-        variables = self._find_variables(root_node)
+        try:
+            if is_notebook:
+                info_logger(f"Converting notebook {file_path} to temporary Python file.")
+                with open(file_path, 'r', encoding='utf-8') as f:
+                    notebook_node = nbformat.read(f, as_version=4)
+                
+                exporter = PythonExporter()
+                python_code, _ = exporter.from_notebook_node(notebook_node)
 
-        return {
-            "file_path": str(file_path),
-            "functions": functions,
-            "classes": classes,
-            "variables": variables,
-            "imports": imports,
-            "function_calls": function_calls,
-            "is_dependency": is_dependency,
-            "lang": self.language_name,
-        }
+                with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.py', encoding='utf-8') as tf:
+                    tf.write(python_code)
+                    temp_py_file = Path(tf.name)
+                
+                # The file to be parsed is now the temporary file
+                file_path = temp_py_file
+
+            with open(file_path, "r", encoding="utf-8") as f:
+                source_code = f.read()
+            
+            tree = self.parser.parse(bytes(source_code, "utf8"))
+            root_node = tree.root_node
+
+            functions = self._find_functions(root_node)
+            functions.extend(self._find_lambda_assignments(root_node))
+            classes = self._find_classes(root_node)
+            imports = self._find_imports(root_node)
+            function_calls = self._find_calls(root_node)
+            variables = self._find_variables(root_node)
+
+            return {
+                "file_path": str(original_file_path), # Always return the original path
+                "functions": functions,
+                "classes": classes,
+                "variables": variables,
+                "imports": imports,
+                "function_calls": function_calls,
+                "is_dependency": is_dependency,
+                "lang": self.language_name,
+            }
+        except Exception as e:
+            error_logger(f"Failed to parse {original_file_path}: {e}")
+            return {"file_path": str(original_file_path), "error": str(e)}
+        finally:
+            if temp_py_file and temp_py_file.exists():
+                os.remove(temp_py_file)
+                info_logger(f"Removed temporary file: {temp_py_file}")
 
     def _find_lambda_assignments(self, root_node):
         functions = []
-        query = self.queries.get('lambda_assignments')
-        if not query: return []
+        query_str = PY_QUERIES.get('lambda_assignments')
+        if not query_str: return []
 
-        for match in query.captures(root_node):
+        for match in execute_query(self.language, query_str, root_node):
             capture_name = match[1]
             node = match[0]
 
@@ -162,8 +188,8 @@ class PythonTreeSitterParser:
 
     def _find_functions(self, root_node):
         functions = []
-        query = self.queries['functions']
-        for match in query.captures(root_node):
+        query_str = PY_QUERIES['functions']
+        for match in execute_query(self.language, query_str, root_node):
             capture_name = match[1]
             node = match[0]
 
@@ -183,11 +209,27 @@ class PythonTreeSitterParser:
                     for p in params_node.children:
                         arg_text = None
                         if p.type == 'identifier':
+                            # Simple parameter: def foo(x)
                             arg_text = self._get_node_text(p)
                         elif p.type == 'default_parameter':
+                            # Parameter with default: def foo(x=5)
                             name_node = p.child_by_field_name('name')
                             if name_node:
                                 arg_text = self._get_node_text(name_node)
+                        elif p.type == 'typed_parameter':
+                            # Typed parameter: def foo(x: int)
+                            name_node = p.child_by_field_name('name')
+                            if name_node:
+                                arg_text = self._get_node_text(name_node)
+                        elif p.type == 'typed_default_parameter':
+                            # Typed parameter with default: def foo(x: int = 5) or def foo(x: str = typer.Argument(...))
+                            name_node = p.child_by_field_name('name')
+                            if name_node:
+                                arg_text = self._get_node_text(name_node)
+                        elif p.type == 'list_splat_pattern' or p.type == 'dictionary_splat_pattern':
+                            # *args or **kwargs
+                            arg_text = self._get_node_text(p)
+                        
                         if arg_text:
                             args.append(arg_text)
 
@@ -212,8 +254,8 @@ class PythonTreeSitterParser:
 
     def _find_classes(self, root_node):
         classes = []
-        query = self.queries['classes']
-        for match in query.captures(root_node):
+        query_str = PY_QUERIES['classes']
+        for match in execute_query(self.language, query_str, root_node):
             capture_name = match[1]
             node = match[0]
 
@@ -249,8 +291,8 @@ class PythonTreeSitterParser:
     def _find_imports(self, root_node):
         imports = []
         seen_modules = set()
-        query = self.queries['imports']
-        for node, capture_name in query.captures(root_node):
+        query_str = PY_QUERIES['imports']
+        for node, capture_name in execute_query(self.language, query_str, root_node):
             if capture_name in ('import', 'from_import_stmt'):
                 # For 'import_statement'
                 if capture_name == 'import':
@@ -317,8 +359,8 @@ class PythonTreeSitterParser:
 
     def _find_calls(self, root_node):
         calls = []
-        query = self.queries['calls']
-        for node, capture_name in query.captures(root_node):
+        query_str = PY_QUERIES['calls']
+        for node, capture_name in execute_query(self.language, query_str, root_node):
             if capture_name == 'name':
                 call_node = node.parent if node.parent.type == 'call' else node.parent.parent
                 full_call_node = call_node.child_by_field_name('function')
@@ -347,8 +389,8 @@ class PythonTreeSitterParser:
 
     def _find_variables(self, root_node):
         variables = []
-        query = self.queries['variables']
-        for match in query.captures(root_node):
+        query_str = PY_QUERIES['variables']
+        for match in execute_query(self.language, query_str, root_node):
             capture_name = match[1]
             node = match[0]
 
@@ -389,18 +431,35 @@ def pre_scan_python(files: list[Path], parser_wrapper) -> dict:
         (class_definition name: (identifier) @name)
         (function_definition name: (identifier) @name)
     """
-    query = parser_wrapper.language.query(query_str)
     
     for file_path in files:
+        temp_py_file = None
         try:
-            with open(file_path, "r", encoding="utf-8") as f:
-                tree = parser_wrapper.parser.parse(bytes(f.read(), "utf8"))
+            source_to_parse = ""
+            if file_path.suffix == '.ipynb':
+                with open(file_path, 'r', encoding='utf-8') as f:
+                    notebook_node = nbformat.read(f, as_version=4)
+                exporter = PythonExporter()
+                python_code, _ = exporter.from_notebook_node(notebook_node)
+                with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.py', encoding='utf-8') as tf:
+                    tf.write(python_code)
+                    temp_py_file = Path(tf.name)
+                with open(temp_py_file, "r", encoding="utf-8") as f:
+                    source_to_parse = f.read()
+            else:
+                with open(file_path, "r", encoding="utf-8") as f:
+                    source_to_parse = f.read()
+
+            tree = parser_wrapper.parser.parse(bytes(source_to_parse, "utf8"))
             
-            for capture, _ in query.captures(tree.root_node):
+            for capture, _ in execute_query(parser_wrapper.language, query_str, tree.root_node):
                 name = capture.text.decode('utf-8')
                 if name not in imports_map:
                     imports_map[name] = []
                 imports_map[name].append(str(file_path.resolve()))
         except Exception as e:
-            logger.warning(f"Tree-sitter pre-scan failed for {file_path}: {e}")
+            warning_logger(f"Tree-sitter pre-scan failed for {file_path}: {e}")
+        finally:
+            if temp_py_file and temp_py_file.exists():
+                os.remove(temp_py_file)
     return imports_map
\ No newline at end of file
